# -*- Mode: Python; test-case-name: codeina.test.test_product_list -*-
# vi:si:et:sw=4:sts=4:ts=4

import os
import StringIO

from codeina.test.common import unittest
from codeina import productlist

class TestProduct(unittest.TestCase):
    def setUp(self):
        xml = """
<products>
  <product id="42"
           nick="wma-dec-bundle"
           rank="75"
           price="EUR 7.00"
           logo-uri="http://download.fluendo.com/images/windowsmedia.png"
           provides="FIXME; element-foobar; decoder-audio/x-wma, wmaversion=(int)3; urisource-mms">
      <name>Windows Media Audio Decoder Bundle</name>
      <name xml:lang="nl">Windows Media Audio Decoder Bundel</name>
      <summary>Everything you need to listen to ASF/WMA audio streams and files</summary>
      <flavor system="Linux" arch="i386" distro="generic" distro-version="any"
              core-req="0.10.0" base-req="0.10.0"
              last-modified="2007-03-26"
              uri="http://download.fluendo.com/plugins/fluendo-ac3-bundle-1.i386.tar.bz2"
              comment="Tested on FC3, FC4, FC5, and Ubuntu 6.10 (edgy)"
              />
  </product>
</products>
"""
        self.handle = StringIO.StringIO(xml)
        self.parser = productlist.ProductListParser()

    def testProduct(self):
        productlist = self.parser.parse(self.handle, "test")
        p = productlist.products[0]
        self.assertEquals(p.price, 7.0)
        self.assertEquals(int(p.rank), 75)
        self.assertEquals(p.name, "Windows Media Audio Decoder Bundle")
        self.assertEquals(p.summary, 
            "Everything you need to listen to ASF/WMA audio streams and files")
        self.assertEquals(len(p.flavors), 1)

    def testNameTranslated(self):
        LANGUAGE = os.environ.get('LANGUAGE', None)
        os.environ['LANGUAGE'] = 'nl_NL'
        productlist = self.parser.parse(self.handle, "test")
        p = productlist.products[0]
        self.assertEquals(p.price, 7.0)
        self.assertEquals(int(p.rank), 75)
        self.assertEquals(p.name, "Windows Media Audio Decoder Bundel")
        self.assertEquals(p.summary, 
            "Everything you need to listen to ASF/WMA audio streams and files")
        if LANGUAGE is not None:
            os.environ['LANGUAGE'] = LANGUAGE
        else:
            del os.environ['LANGUAGE']
        
